==> dokuwiki_0.0.20050922.orig.tar.gz: dokuwiki-2005-09-22/inc/lang/it/lang.php <==
<?php
/**
 * italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @mod by     Roberto Bolli <http://www.rbent.it/>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Modifica questa pagina';
$lang['btn_source'] = 'Mostra sorgente';
$lang['btn_show']   = 'Mostra pagina';
$lang['btn_create'] = 'Crea questa pagina';
$lang['btn_search'] = 'Cerca';
$lang['btn_save']   = 'Salva';
$lang['btn_preview']= 'Anteprima';
$lang['btn_top']    = 'Torna su';
$lang['btn_newer']  = '<< più recenti';
$lang['btn_older']  = 'meno recenti >>';
$lang['btn_revs']   = 'Revisioni precedenti';
$lang['btn_recent'] = 'Ultime modifiche';
$lang['btn_upload'] = 'Invia file';
$lang['btn_cancel'] = 'Annulla';
$lang['btn_index']  = 'Indice';
$lang['btn_secedit']= 'Modifica';
$lang['btn_login']  = 'Entra';
$lang['btn_logout'] = 'Esci';
$lang['btn_admin']  = 'Amministrazione';
$lang['btn_update'] = 'Aggiorna';
$lang['btn_delete'] = 'Cancella';
$lang['btn_back']   = 'Indietro';
$lang['btn_backtomedia'] = 'Torna al selettore Mediafile';

$lang['loggedinas'] = 'Collegato come';
$lang['user']       = 'Nome utente';
$lang['pass']       = 'Password';
$lang['passchk']    = 'Ripeti password';
$lang['remember']   = 'Ricorda automaticamente';
$lang['fullname']   = 'Nome completo';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registra';
$lang['badlogin']   = 'Il nome utente o la password non è valida.';

$lang['regmissing'] = 'Devi riempire tutti i campi.';
$lang['reguexists'] = 'Il nome nome utente immesso esiste già.';
$lang['regsuccess'] = 'L\'utente è stato creato. La tua password ti è stata inviata con un messaggio di posta elettronica.';
$lang['regsuccess2']= 'L\'utente è stato creato.';
$lang['regmailfail']= 'Sembra che ci sia stato un errore nell\'invio del messaggio e-mail. Per favore contatta il tuo amministratore!';
$lang['regbadmail'] = 'L\'indirizzo email fornito sembra essere non valido - se pensi che ci sia un errore contatta il tuo amministratore';
$lang['regbadpass'] = 'Le due password inserite non coincidono, prova di nuovo.';
$lang['regpwmail']  = 'La tua password DokuWiki';
$lang['reghere']    = 'Non hai ancora un accesso? Registrati qui.';

$lang['txt_upload']   = 'Seleziona un file da caricare';
$lang['txt_filename'] = 'Inserisci un "wikiname" (opzionale)';
$lang['txt_overwrt']  = 'Sovrascrivi file esistente';
$lang['lockedby']     = 'Attualmente bloccato da';
$lang['lockexpire']   = 'Il blocco scade alle';
$lang['willexpire']   = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';

$lang['notsavedyet'] = 'Alcune modifiche non salvate andranno perse.\nSei sicuro?';
$lang['rssfailed']   = 'Si è verifico un errore cercando questo feed : ';
$lang['nothingfound']= 'Nessun risultato trovato.';

$lang['mediaselect'] = 'Selezione dei file';
$lang['fileupload']  = 'File caricato';
$lang['uploadsucc']  = 'Invio riuscito';
$lang['uploadfail']  = 'Invio fallito. Contatta l\'amministratore.';
$lang['uploadwrong'] = 'Invio rifiutato. Questa estensione di file non è ammessa';
$lang['uploadexist'] = 'File esistente. Lavoro abortito.';
$lang['deletesucc']  = 'Il file "%s" è stato cancellato.';
$lang['deletefail']  = '"%s" non può essere cancellato - verifica i permessi.';
$lang['mediainuse']  = 'Il file "%s" on è stato cancellato - è ancora in uso.';
$lang['namespaces']  = 'Categorie';
$lang['mediafiles']  = 'File disponibili in';

$lang['reference']   = 'Riferimenti a';
$lang['ref_inuse']   = 'Il file non può essere cancellato in quanto è ancora utilizzato dalle seguenti pagine:';
$lang['ref_hidden']  = 'Alcuni riferimenti sono presenti in pagine per le quali non hai i permessi di lettura';

$lang['hits']       = 'Occorrenze trovate';
$lang['quickhits']  = 'Pagine trovate';
$lang['toc']        = 'Indice';
$lang['current']    = 'versione corrente';
$lang['yours']      = 'la tua versione';
$lang['diff']       = 'differenze con la versione attuale';
$lang['line']       = 'Linea';
$lang['breadcrumb'] = 'Traccia';
$lang['lastmod']    = 'Ultima modifica';
$lang['by']         = 'da';
$lang['deleted']    = 'cancellata';
$lang['created']    = 'creata';
$lang['restored']   = 'versione precedente ripristinata';
$lang['summary']    = 'Oggetto della modifica';

$lang['mail_newpage'] = 'pagina aggiunta:';
$lang['mail_changed'] = 'pagina modificata:';

$lang['nosmblinks'] = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.\nPuoi fare un copia/incolla di questo collegamento.';

$lang['qb_alert']   = 'Puoi inserire il testo che vuoi formattare.\nSarà aggiunto alla fine del documento.';
$lang['qb_bold']    = 'Grassetto';
$lang['qb_italic']  = 'Italico';
$lang['qb_underl']  = 'Sottolineato';
$lang['qb_code']    = 'Codice';
$lang['qb_strike']  = 'Sbarrato';
$lang['qb_h1']      = 'Intestazione (livello 1)';
$lang['qb_h2']      = 'Sottointestazione (livello 2)';
$lang['qb_h3']      = 'Sottointestazione (livello 3)';
$lang['qb_h4']      = 'Sottointestazione (livello 4)';
$lang['qb_h5']      = 'Sottointestazione (livello 5)';
$lang['qb_link']    = 'Collegamento interno';
$lang['qb_extlink'] = 'Collegamento esterno';
$lang['qb_hr']      = 'Riga orizzontale';
$lang['qb_ol']      = 'Elenco numerato';
$lang['qb_ul']      = 'Elenco puntato';
$lang['qb_media']   = 'Inserisci immagino o altri file';
$lang['qb_sig']     = 'Inserisci la firma';

$lang['del_confirm']= 'Cancellare questa voce?';

$lang['admin_acl']  = 'Access Control List Management...';
$lang['admin_register']= 'Aggiungi un nuovo utente...';

$lang['acl_group']  = 'Gruppo';
$lang['acl_user']   = 'Utente';
$lang['acl_perms']  = 'Permessi per';
$lang['page']       = 'Pagina';
$lang['namespace']  = 'Categoria';

$lang['acl_perm1']  = 'Lettura';
$lang['acl_perm2']  = 'Modifica';
$lang['acl_perm4']  = 'Creazione';
$lang['acl_perm8']  = 'Upload';
$lang['acl_perm16'] = 'Cancellazione';
$lang['acl_new']    = 'Aggiungi nuovo record';

$lang['spell_start'] = 'Dizionario';
$lang['spell_stop']  = 'Resume Editing';
$lang['spell_wait']  = 'Attendere...';
$lang['spell_noerr'] = 'Nessun errore trovato';
$lang['spell_nosug'] = 'Nessun suggerimento';
$lang['spell_change']= 'Cambia';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/it/lang.php <==
<?php
/**
 * italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author     Roberto Bolli <http://www.rbnet.it/>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Modifica questa pagina';
$lang['btn_source'] = 'Mostra sorgente';
$lang['btn_show']   = 'Mostra pagina';
$lang['btn_create'] = 'Crea questa pagina';
$lang['btn_search'] = 'Cerca';
$lang['btn_save']   = 'Salva';
$lang['btn_preview']= 'Anteprima';
$lang['btn_top']    = 'Torna su';
$lang['btn_newer']  = '<< più recenti';
$lang['btn_older']  = 'meno recenti >>';
$lang['btn_revs']   = 'Revisioni precedenti';
$lang['btn_recent'] = 'Ultime modifiche';
$lang['btn_upload'] = 'Invia file';
$lang['btn_cancel'] = 'Annulla';
$lang['btn_index']  = 'Indice';
$lang['btn_secedit']= 'Modifica';
$lang['btn_login']  = 'Entra';
$lang['btn_logout'] = 'Esci';
$lang['btn_admin']  = 'Amministrazione';
$lang['btn_update'] = 'Aggiorna';
$lang['btn_delete'] = 'Cancella';
$lang['btn_back']   = 'Indietro';
$lang['btn_backlink']    = "Backlinks";
$lang['btn_backtomedia'] = 'Torna al selettore Mediafile';
$lang['btn_subscribe']   = 'Sottoscrivi modifiche';
$lang['btn_unsubscribe'] = 'Cancella sottoscrizione';

$lang['loggedinas'] = 'Collegato come';
$lang['user']       = 'Nome utente';
$lang['pass']       = 'Password';
$lang['passchk']    = 'Ripeti password';
$lang['remember']   = 'Ricorda automaticamente';
$lang['fullname']   = 'Nome completo';
$lang['email']      = 'E-Mail';
$lang['register']   = 'Registra';
$lang['badlogin']   = 'Il nome utente o la password non è valida.';

$lang['regmissing'] = 'Devi riempire tutti i campi.';
$lang['reguexists'] = 'Il nome nome utente immesso esiste già.';
$lang['regsuccess'] = 'L\'utente è stato creato. La tua password ti è stata inviata con un messaggio di posta elettronica.';
$lang['regsuccess2']= 'L\'utente è stato creato.';
$lang['regmailfail']= 'Sembra che ci sia stato un errore nell\'invio del messaggio e-mail. Per favore contatta il tuo amministratore!';
$lang['regbadmail'] = 'L\'indirizzo email fornito sembra essere non valido - se pensi che ci sia un errore contatta il tuo amministratore';
$lang['regbadpass'] = 'Le due password inserite non coincidono, prova di nuovo.';
$lang['regpwmail']  = 'La tua password DokuWiki';
$lang['reghere']    = 'Non hai ancora un accesso? Registrati qui.';

$lang['txt_upload']   = 'Seleziona un file da caricare';
$lang['txt_filename'] = 'Inserisci un "wikiname" (opzionale)';
$lang['txt_overwrt']  = 'Sovrascrivi file esistente';
$lang['lockedby']     = 'Attualmente bloccato da';
$lang['lockexpire']   = 'Il blocco scade alle';
$lang['willexpire']   = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';

$lang['notsavedyet'] = 'Alcune modifiche non salvate andranno perse.\nContinuare?';

$lang['rssfailed']   = 'Si è verificato un errore cercando questo feed: ';
$lang['nothingfound']= 'Nessun risultato trovato.';

$lang['mediaselect'] = 'Selezione dei file';
$lang['fileupload']  = 'File caricato';
$lang['uploadsucc']  = 'Invio riuscito';
$lang['uploadfail']  = 'Invio fallito. Contatta l\'amministratore.';
$lang['uploadwrong'] = 'Invio rifiutato. Questa estensione di file non è ammessa';
$lang['uploadexist'] = 'File esistente. Lavoro abortito.';
$lang['deletesucc']  = 'Il file "%s" è stato cancellato.';
$lang['deletefail']  = '"%s" non può essere cancellato - verifica i permessi.';
$lang['mediainuse']  = 'Il file "%s" on è stato cancellato - è ancora in uso.';
$lang['namespaces']  = 'Categorie';
$lang['mediafiles']  = 'File disponibili in';

$lang['reference']   = 'Riferimenti a';
$lang['ref_inuse']   = 'Il file non può essere cancellato in quanto è ancora utilizzato dalle seguenti pagine:';
$lang['ref_hidden']  = 'Alcuni riferimenti sono presenti in pagine per le quali non hai i permessi di lettura';

$lang['hits']       = 'Occorrenze trovate';
$lang['quickhits']  = 'Pagine trovate';
$lang['toc']        = 'Indice';
$lang['current']    = 'versione corrente';
$lang['yours']      = 'la tua versione';
$lang['diff']       = 'differenze con la versione attuale';
$lang['line']       = 'Linea';
$lang['breadcrumb'] = 'Traccia';
$lang['lastmod']    = 'Ultima modifica';
$lang['by']         = 'da';
$lang['deleted']    = 'cancellata';
$lang['created']    = 'creata';
$lang['restored']   = 'versione precedente ripristinata';
$lang['summary']    = 'Oggetto della modifica';

$lang['mail_newpage'] = 'pagina aggiunta:';
$lang['mail_changed'] = 'pagina modificata:';

$lang['nosmblinks'] = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.\nPuoi fare un copia/incolla di questo collegamento.';

$lang['qb_alert']   = 'Puoi inserire il testo che vuoi formattare.\nSarà aggiunto alla fine del documento.';
$lang['qb_bold']    = 'Grassetto';
$lang['qb_italic']  = 'Italico';
$lang['qb_underl']  = 'Sottolineato';
$lang['qb_code']    = 'Codice';
$lang['qb_strike']  = 'Sbarrato';
$lang['qb_h1']      = 'Intestazione (livello 1)';
$lang['qb_h2']      = 'Sottointestazione (livello 2)';
$lang['qb_h3']      = 'Sottointestazione (livello 3)';
$lang['qb_h4']      = 'Sottointestazione (livello 4)';
$lang['qb_h5']      = 'Sottointestazione (livello 5)';
$lang['qb_link']    = 'Collegamento interno';
$lang['qb_extlink'] = 'Collegamento esterno';
$lang['qb_hr']      = 'Riga orizzontale';
$lang['qb_ol']      = 'Elenco numerato';
$lang['qb_ul']      = 'Elenco puntato';
$lang['qb_media']   = 'Inserisci immagino o altri file';
$lang['qb_sig']     = 'Inserisci la firma';

$lang['del_confirm']= 'Cancellare questa voce?';
$lang['admin_register']= 'Aggiungi un nuovo utente';

$lang['spell_start'] = 'Dizionario';
$lang['spell_stop']  = 'Resume Editing';
$lang['spell_wait']  = 'Attendere...';
$lang['spell_noerr'] = 'Nessun errore trovato';
$lang['spell_nosug'] = 'Nessun suggerimento';
$lang['spell_change']= 'Cambia';

$lang['metaedit']    = 'Modifica Metadata';
$lang['metasaveerr'] = 'Scrittura metadata fallita';
$lang['metasaveok']  = 'Metadata salvati';
$lang['img_backto']  = 'Torna a';
$lang['img_title']   = 'Titolo';
$lang['img_caption'] = 'Descrizione';
$lang['img_date']    = 'Data';
$lang['img_fname']   = 'Nome File';
$lang['img_fsize']   = 'Grandezza';
$lang['img_artist']  = 'Autore';
$lang['img_copyr']   = 'Copyright';
$lang['img_format']  = 'Formato';
$lang['img_camera']  = 'Camera';
$lang['img_keywords']= 'Parole chiave';

$lang['subscribe_success']  = '%s è stato aggiunto alla lista di controllo per la pagina %s';
$lang['subscribe_error']    = 'Si è verificato un errore durante l\'aggiunta di %s alla lista di controllo per la pagina %s';
$lang['subscribe_noaddress']= 'Non c\'è alcun indirizzo associato con il tuo login, non puoi sottoscrivere alcuna lista';
$lang['unsubscribe_success']= '%s è stato rimosso dalla lista di controllo per la pagina %s';
$lang['unsubscribe_error']  = 'Si è verificato un errore durante la rimozione di %s dalla lista di controllo per la pagina %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :
